'''Структуры данных'''

import enum


class Base(str, enum.Enum):
    '''Основание (закон) проведения закупки'''
    FZ44 = 'fz44'
    FZ223 = 'fz223'
    PPRF615 = 'pprf615'

    @classmethod
    def from_name(cls, name: str):
        '''Получить объект из наименования'''
        for source in list(cls):
            if source.name == name.upper():
                return source
        raise ValueError('Неизвестное значение основания')

    def __str__(self):
        return self.name.lower()


class SubsystemType(str, enum.Enum):
    '''Тип подсистемы для отбора документов'''

    #
    # --- Подсистемы 44-ФЗ
    #

    # --- Библиотека типовых контрактов;
    BTK = 'BTK'
    # --- подсистема размещения извещений
    #     (без протоколов со сведениями об участниках) ?
    PRIZ = 'PRIZ'
    # --- подсистема заключения контрактов;
    RPEC = 'RPEC'
    # --- подсистема заключения контрактов в ЛКП;
    PZKLKP = 'PZKLKP'
    # --- реестр планов графиков с 2020 года;
    RPGZ = 'RPGZ'
    # --- Реестр правил нормирования закупок;
    RPNZ = 'RPNZ'
    # --- Реестр дополнительной информации о закупках и контрактах;
    RDI = 'RDI'
    # --- реестр контрактов;
    RGK = 'RGK'
    # --- Электронное актирование;
    EA = 'EA'
    # --- Односторонний отказ;
    UR = 'UR'
    # --- Реестр электронных контрактов;
    REC = 'REC'
    # --- Реестр жалоб;
    RJ = 'RJ'
    # --- Реестр плановых проверок;
    RPP = 'RPP'
    # --- Реестр внеплановых проверок;
    RVP = 'RVP'
    # --- Реестр результатов контроля;
    RRK = 'RRK'

    # --- Реестр извещений и протоколов 615;
    PPRF615 = 'PPRF615'
    # --- Реестр договоров 615;
    RD615 = 'RD615'
    # --- Личный кабинет органа контроля;
    LKOK = 'LKOK'
    # --- Отчеты заказчика.
    OZ = 'OZ'

    #
    # --- Подсистемы 223-ФЗ
    #

    # --- Отчетность по договорам;
    OD223 = 'OD223'
    # --- Реестр договоров;
    RD223 = 'RD223'
    # --- Реестр жалоб;
    RJ223 = 'RJ223'
    # --- Реестр плановых проверок;
    RPP223 = 'RPP223'
    # --- Реестр планов закупок;
    RPZ223 = 'RPZ223'
    # --- Реестр извещений о закупках;
    RI223 = 'RI223'
    # --- Реестр заказчиков;
    RZ223 = 'RZ223'
    # --- Информация об объеме выручки;
    OV223 = 'OV223'
    # --- Типовые положения о закупках;
    TPOZ223 = 'TPOZ223'
    # --- Положения о закупках;
    POZ223 = 'POZ223'
    # --- Подсистема оценки и мониторинга
    POM223 = 'POM223'


class NsiKind(str, enum.Enum):
    '''Вид выгрузки.

    all - полная выгузка справочника
    inc - инкрементальная выгрузка
    '''
    ALL = 'all'
    INC = 'inc'
